/*
 * Copyright (c) 1996, 2009 Hellmuth Michaelis.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *---------------------------------------------------------------------------
 *
 *	setnetparm - defs.h
 *	-------------------
 *
 *	$Id: defs.h,v 1.3 2009/02/03 13:39:57 hm Exp $
 *
 *---------------------------------------------------------------------------*/

#include <unistd.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <stdarg.h>
#include <ctype.h>
#include <curses.h>
#include <sys/time.h>

#define	VERS		"3"
#define REV		"80"

#define TABLEN	25	/* maximum table entries, ADJUST for more */

#define FILE_DIR	"/etc/mobile"
#define FILE_DEFAULTS	"/etc/mobile/laptop.curr"
#define FILE_MENUDEFS	"/etc/mobile/laptop.menu"

#define MAXLINELEN	1024	/* max length of a line */

/* input types for curgets() */
#define TYPE_IP		0	/* dotted quad */
#define TYPE_HOST	1	/* hostname */
#define TYPE_DOMAIN	2	/* domainname */
#define TYPE_IFF	3	/* interfaceflags */

#define M_LINE		13	/* menu line pos */
#define M_COL		3

#define POS_DEF		1
#define POS_DU		(POS_DEF+1)
#define POS_IP		(POS_DU+1)
#define POS_SN		(POS_IP+1)
#define POS_FL		(POS_SN+1)
#define POS_HN		(POS_FL+1)
#define POS_DN		(POS_HN+1)
#define POS_GW		(POS_DN+1)
#define POS_NS		(POS_GW+1)
#define POS_SH		(POS_NS+1)

#define POS_COLNEW	47

#define C_LINE		12	/* data entry line pos */
#define	C_COL		10

/* some control characters */

#define CR		0x0d
#define LF		0x0a
#define TAB		0x09
#define BS		0x08
#define DEL		0x7f
#define SPACE		0x20
#define BEL		0x07
#define ESC		0x1b

/* keycodes for cursor motion */

#define	K_UP		0x10		/* ^P */
#define K_DOWN		0x0e		/* ^N */
#define	K_LEFT		0x02		/* ^B */
#define	K_RIGHT		0x06		/* ^F */
#define K_TAB		0x09		/* tab */
#define K_NEXT		0x16		/* ^V */
#define K_PREV		0x1a		/* ^Z */
#define K_QUIT		0x04		/* ^D */
#define K_REF		0x0c		/* ^L */
#define K_MARK		0x01		/* ^A */
#define	K_ECHO		0x17		/* ^W */
#define K_UMARK		0x15		/* ^U */

#define CNTRL_AT 0x00
#define CNTRL_A	0x01
#define CNTRL_B	0x02
#define CNTRL_C	0x03
#define CNTRL_D	0x04
#define CNTRL_E	0x05
#define CNTRL_F	0x06
#define CNTRL_G	0x07
#define CNTRL_H	0x08
#define CNTRL_I	0x09
#define CNTRL_J	0x0A
#define CNTRL_K	0x0B 
#define CNTRL_L	0x0C
#define CNTRL_M	0x0D
#define CNTRL_N	0x0E
#define CNTRL_O	0x0F
#define CNTRL_P	0x10
#define CNTRL_Q	0x11
#define CNTRL_R	0x12
#define CNTRL_S	0x13
#define CNTRL_T	0x14
#define CNTRL_U	0x15
#define CNTRL_V	0x16
#define CNTRL_W	0x17
#define CNTRL_X	0x18
#define CNTRL_Y	0x19
#define CNTRL_Z	0x1A

/* states for reading config entries */
enum states {
	ST_TIMEOUT = 0,
	ST_INTERFACELIST,
	ST_HEADL,
	ST_IFACE,
	ST_IPADR,
	ST_SNMSK,
	ST_IFLGS,
	ST_HNAME,
	ST_DNAME,
	ST_GWADR,
	ST_NSERV,
	ST_SCRIPT
};

#ifdef MAIN

#define TABFIX 3

char *mainmenu[TABLEN+TABFIX];

char *mitem0 = "[ Use the \"Current Values\" and exit ]";
char *mitem1 = "[ Enter new values for everything   ]";
char *mitem2 = "[ Use the \"New Values\" and exit     ]";

int keytimeout;

char interfaces[1024];

#define TIMEOUT_MAX	300	/* max timeout to wait for first keystroke */

#define ITEM_USE_CURR	1
#define ITEM_ENTER	2
#define ITEM_USE_NEW	3
#define ITEM_CUSTOM	4

char	*mainmenutitle = "Network Configuration";

char	m_menuitem[TABLEN][MAXLINELEN];

char	*ipaddress = "IP Address";
char	ipaddr[MAXLINELEN]  = "";
char	nipaddr[MAXLINELEN] = "";
char	m_ipaddr[TABLEN][MAXLINELEN];

char	*subnetmask = "Subnetmask";
char	snmask[MAXLINELEN]  = "";
char	nsnmask[MAXLINELEN] = "";
char	m_snmask[TABLEN][MAXLINELEN];

char	*ifconfigflags = "ifconfig Flags";
char	ifflags[MAXLINELEN]  = "";
char	nifflags[MAXLINELEN] = "";
char	m_ifflags[TABLEN][MAXLINELEN];

char	*gwaddress = "Gateway";
char	gwaddr[MAXLINELEN]  = "";
char	ngwaddr[MAXLINELEN] = "";
char	m_gwaddr[TABLEN][MAXLINELEN];

char	*hostname = "Hostname";
char	hname[MAXLINELEN]  = "";
char	nhname[MAXLINELEN] = "";
char	m_hname[TABLEN][MAXLINELEN];

char	*domainname = "Domainname";
char	dname[MAXLINELEN]  = "";
char	ndname[MAXLINELEN] = "";
char	m_dname[TABLEN][MAXLINELEN];

char	*nameserver = "Nameserver";
char	nmserver[MAXLINELEN]  = "";
char	nnmserver[MAXLINELEN] = "";
char	m_nmserver[TABLEN][MAXLINELEN];

char	*shellscript = "Shellscript";
char	shscript[MAXLINELEN]  = "";
char	nshscript[MAXLINELEN] = "";
char	m_nshscript[TABLEN][MAXLINELEN];

char	*interface = "Interface";
char	iface[MAXLINELEN]  = "";
char	niface[MAXLINELEN] = "";
char	m_niface[TABLEN][MAXLINELEN];

char	*nodefs = "File with default settings does not exist";
char	*nomdefs = "File with menu settings does not exist";

char	*nowrite = "ERROR: cannot open file for writing!";

char	*defs = "What         Current Values                New Values";
char	*defsu ="-----------  ----------------------------- -----------------------------";

#endif

extern void curgets ( char *str, int len, int y, int x, char *title, int hide, char *defstr, char *help, int type);
extern int menubar ( int y, int x, char *menu[], int nitems, int pos, char *title, int timeout, int firstflag);

/*---------------------------------- EOF ------------------------------------*/

struct entry
{
	char *headl;
	char *iface;
	char *ipadr;
	char *snmsk;	
	char *iflgs;
	char *hname;
	char *dname;
	char *gwadr;
	char *nserv;	
	char *script;

	struct entry *next_entry;
};
	
struct entry *first_entry;
