/*
 * Copyright (c) 2004, 2009 Hellmuth Michaelis.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *---------------------------------------------------------------------------
 *
 *	setnetparm - menubar.c
 *	----------------------
 *
 *	$Id: menubar.c,v 1.3 2009/02/03 13:39:57 hm Exp $
 *
 *---------------------------------------------------------------------------*/

#include "defs.h"

#define	MAXNAMELEN	70

#include <curses.h>
#include <menu.h>

void print_in_middle(WINDOW *win, int starty, int startx, int width, char *string);

/*---------------------------------------------------------------------------*
 *	create and process a menubar in a menu window
 *---------------------------------------------------------------------------*/
int
menubar(int y, int x, char *menu_strgs[], int nitems, int pos, char *title,
	int timeout, int first)
{
	ITEM **menu_items;
	MENU *menu;
        WINDOW *menu_window;
        int i;
	int c;
	int firstflag = 1;
	
        menu_items = (ITEM **)calloc(nitems+1, sizeof(ITEM *));

        for(i = 0; i < nitems; i++)
                menu_items[i] = new_item(menu_strgs[i], "");
	menu_items[i] = (ITEM *)0;
	
	/* create menu */
	menu = new_menu((ITEM **)menu_items);

	/* create the menu window */
        menu_window = newwin(10, 60, 13, 3);

	noecho();
	crmode();
        keypad(menu_window, TRUE);
     
	/* set main window and sub window */
        set_menu_win(menu, menu_window);
        set_menu_sub(menu, derwin(menu_window, 8, 58, 1, 1));
	set_menu_format(menu, 8, 1);
			
	/* set menu mark to the string " * " */
        set_menu_mark(menu, "-> ");

	/* print a border around the main window and print a title */
        box(menu_window, 0, 0);

	print_in_middle(menu_window, 0, 0, 40, title);

	set_current_item(menu, menu_items[pos]);	

	/* post the menu */
	post_menu(menu);
	wrefresh(menu_window);

	refresh();

	/* timout handling for first keystroke */

	if(first && firstflag)
	{
		char tostring[MAXLINELEN];
		int secsleft = timeout;
		WINDOW *towin;
		fd_set set;
		struct timeval timeout;

		sprintf(tostring, "Time left for first keystroke: %3d seconds", secsleft);

		towin = newwin(3, strlen(tostring)+3, 9, 35);
		wborder(towin, 0, 0, 0, 0, 0, 0, 0, 0);
		mvwprintw(towin, 1, 1, "%s", tostring);
		wrefresh(towin);
		
		firstflag = 0;

		for(;;)
		{
			FD_ZERO(&set);
			FD_SET(STDIN_FILENO, &set);
			timeout.tv_sec = 1;
			timeout.tv_usec = 0;

			if((select(STDIN_FILENO + 1, &set, NULL, NULL, &timeout)) <= 0)
			{
				secsleft--;

				if(secsleft)
				{
					mvwprintw(towin, 1, 1, "Time left for first keystroke: %3d seconds", secsleft);
					wrefresh(towin);
					continue;
				}
				else
				{
					wclear(towin);
					wrefresh(towin);
					delwin(towin);
			                wclear(menu_window);
        		                        wrefresh(menu_window);
					delwin(menu_window);
					return(-1);
				}
			}
			else
			{
				break;
			}
		}
		wclear(towin);
		wrefresh(towin);
		delwin(towin);

		touchwin(menu_window);
		wrefresh(menu_window);
	}
	
	for(;;)
	{
		c = wgetch(menu_window);

		switch(c)
	        {
			case KEY_DOWN:
				menu_driver(menu, REQ_DOWN_ITEM);
				break;

			case KEY_UP:
				menu_driver(menu, REQ_UP_ITEM);
				break;

			case KEY_NPAGE:
				menu_driver(menu, REQ_SCR_DPAGE);
				break;

			case KEY_PPAGE:
				menu_driver(menu, REQ_SCR_UPAGE);
				break;

			case CR:
			case LF:
			case KEY_ENTER:			
			{
				int pos;

				pos = item_index(current_item(menu));

				unpost_menu(menu);
				free_menu(menu);

				for(i = 0; i < nitems; ++i)
					free_item(menu_items[i]);

				endwin();

				return(pos+1);
			}
		}
                wrefresh(menu_window);
	}	
	return(-1);
}

/*---------------------------------------------------------------------------*
 *	print window title 
 *---------------------------------------------------------------------------*/
void
print_in_middle(WINDOW *win, int starty, int startx, int width, char *string)
{
	int length;
	int x;
	int y;
	float temp;

	if(win == NULL)
		win = stdscr;

	getyx(win, y, x);

	if(startx != 0)
		x = startx;
	if(starty != 0)
		y = starty;
	if(width == 0)
		width = 80;

	length = strlen(string);
	temp = (width - length)/ 2;
	x = startx + (int)temp;

	wstandout(win);
	mvwprintw(win, y, x, "%s", string);
	wstandend(win);

	refresh();
}

/* EOF */
